@@ -64,16 +64,19 @@ impl Nat for i32 {
 }
 impl Int for i32 {}
 
+#[derive(Debug)]
 enum ParsingYear {
     Unspecified,
     Year(i32),
     PrefixSuffix(i32, u8),
 }
+#[derive(Debug)]
 enum ParsingDayOfYear {
     Unspecified,
     MonthDay(Month, u8),
     DayOfYear(u16),
 }
+#[derive(Debug)]
 enum ParsingHour {
     Unspecified,
     FullDay(u8),
@@ -295,7 +298,7 @@ impl<'a> Collector for ParseCollector<'a> {
         if (1..=12).contains(&hour) {
             let hour = hour % 12;
             match &mut self.hour {
-                ParsingHour::Unspecified => self.hour = ParsingHour::FullDay(hour),
+                ParsingHour::Unspecified => self.hour = ParsingHour::HalfDay(hour, false),
                 // Prefer full day over halfday + am/pm.
                 ParsingHour::FullDay(_) => {}
                 ParsingHour::HalfDay(current, _) => *current = hour,
@@ -415,7 +418,7 @@ impl<'a> Collector for ParseCollector<'a> {
             }
             match &mut self.year {
                 ParsingYear::Unspecified => {
-                    self.year = ParsingYear::PrefixSuffix(if y < 69 { 19 } else { 20 }, y)
+                    self.year = ParsingYear::PrefixSuffix(if y < 69 { 20 } else { 19 }, y)
                 }
                 // Prefer year over (year prefix, year suffix).
                 ParsingYear::Year(_) => {}
@@ -509,7 +512,7 @@ impl<'a> Collector for ParseCollector<'a> {
                 if ampm {
                     h + 12
                 } else {
-                    0
+                    h
                 }
             }
         };
@@ -533,22 +536,159 @@ mod tests {
     use time::macros::{datetime, offset};
 
     #[test]
-    fn test_zone() -> Result<(), super::Error> {
+    fn test_simple_parse() -> Result<(), super::Error> {
         assert_eq!(
-            parse_date_time_maybe_with_zone("%FT%TZ", "2015-03-05T23:51:47Z")?,
-            (datetime!(2015-03-05 23:51:47), None)
+            parse_date_time_maybe_with_zone("%a %A %a", "wED Wed weDnesDay")?,
+            (datetime!(1900-01-01 00:00:00), None)
         );
         assert_eq!(
-            parse_date_time_maybe_with_zone("%FT%T %z", "2015-03-05T23:51:47 -1234")?,
+            parse_date_time_maybe_with_zone("%b %B %b", "feB FEb feburaRy")?,
+            (datetime!(1900-02-01 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%c", "Sun Mar  6 12:34:56 2022")?,
+            (datetime!(2022-03-06 12:34:56), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%C", "20")?,
+            (datetime!(2000-01-01 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%d", "5")?,
+            (datetime!(1900-01-05 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%e", "5")?,
+            (datetime!(1900-01-05 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%D", "3 /6/22")?,
+            (datetime!(2022-03-06 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%F", "2022-03-06")?,
+            (datetime!(2022-03-06 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%H", "2")?,
+            (datetime!(1900-01-01 2:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%k", "2")?,
+            (datetime!(1900-01-01 2:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%I", "2")?,
+            (datetime!(1900-01-01 2:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%l", "12")?,
+            (datetime!(1900-01-01 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%j", "38")?,
+            (datetime!(1900-02-07 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%m", "8")?,
+            (datetime!(1900-08-01 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%M", "8")?,
+            (datetime!(1900-01-01 00:08:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%n%t ", "   ")?,
+            (datetime!(1900-01-01 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%I %p", "12 AM")?,
+            (datetime!(1900-01-01 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%I %p", "1 AM")?,
+            (datetime!(1900-01-01 01:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%I %p", "1 pm")?,
+            (datetime!(1900-01-01 13:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%I %p", "12 pm")?,
+            (datetime!(1900-01-01 12:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%r", "12:34:56 PM")?,
+            (datetime!(1900-01-01 12:34:56), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%r", "12:34:56 AM")?,
+            (datetime!(1900-01-01 00:34:56), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%R", "12: 4")?,
+            (datetime!(1900-01-01 12:04:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%S", "01")?,
+            (datetime!(1900-01-01 00:00:01), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%T", "01:23:45")?,
+            (datetime!(1900-01-01 01:23:45), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%U", "1")?,
+            (datetime!(1900-01-01 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%w", "1")?,
+            (datetime!(1900-01-01 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%W", "1")?,
+            (datetime!(1900-01-01 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%x", "3/6/22")?,
+            (datetime!(2022-03-06 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%X", "12:34:5")?,
+            (datetime!(1900-01-01 12:34:05), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%y", "12")?,
+            (datetime!(2012-01-01 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%y", "70")?,
+            (datetime!(1970-01-01 00:00:00), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%Y", "70")?,
+            (datetime!(0070-01-01 00:00:00), None)
+        );
+        Ok(())
+    }
+
+    #[test]
+    fn test_zone() -> Result<(), super::Error> {
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%FT%TZ", "2022-03-06T12:34:56Z")?,
+            (datetime!(2022-03-06 12:34:56), None)
+        );
+        assert_eq!(
+            parse_date_time_maybe_with_zone("%FT%T %z", "2022-03-06T12:34:56 -1234")?,
             (
-                datetime!(2015-03-05 23:51:47),
+                datetime!(2022-03-06 12:34:56),
                 Some(TimeZoneSpecifier::Offset(offset!(-12:34)))
             )
         );
         assert_eq!(
-            parse_date_time_maybe_with_zone("%FT%T %Z", "2015-03-05T23:51:47 JST")?,
+            parse_date_time_maybe_with_zone("%FT%T %Z", "2022-03-06T12:34:56 JST")?,
             (
-                datetime!(2015-03-05 23:51:47),
+                datetime!(2022-03-06 12:34:56),
                 Some(TimeZoneSpecifier::Name("JST"))
             )
         );
